/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.cache.api;

/**
 * This  interface is  to be implemented  at the applicative  level, to
 * ensure an  appropriate management of objects held  in cache.
 * For instances,  the event listener  can implement a
 * callback to deal with housekeeping of complex objects (e.g. closing
 * OS resources allocated to the corresponding object), after it is
 * notified of their corresponding eviction.
 *
 * @author Luciano Garcia-Banuelos (Luciano.Garcia@imag.fr)
 * @version 0.0.0
 */
public interface CacheEventListener {
    /**
	 * An entry has been added in the cache.
	 * @param event describes the added entry
	 */
	void entryBound(CacheEvent event);

    /**
	 * An entry has been evicted from the cache.
	 * @param event describes the evicted entry
	 */
	void entryUnbound(CacheEvent event);
}
