/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.cache.api;

import java.util.Collection;

/**
 * This interface is used by the replacement manager to evict
 * an instance from the cache. The primitive CacheManager component and the
 * replacement manager implement this interface.
 * In some implementation the instance is not evicted on the call of the unbind
 * method weither the java Garbage Collector and the strengh link to entry.
 *
 * @author Luciano Garcia-Banuelos (Luciano.Garcia@imag.fr)
 */
public interface UnbindManager {

    /**
	 * Evicts an instance from the cache.
	 * @param oid is the identifier associated to the cache entry to evict
     * @param force is a boolean value indicating if the cache must remove the
     * entry or let the GC does its job.
	 * @throws CacheException is raised when the entry is already unbound from
	 * the cache.
	 */
	boolean unbind(Object oid, boolean force) throws CacheException;

	/**
	 * Evicts instances from the cache.
	 * @param oids is a collection of the identifier associated to cache entries
	 * to evict
	 * @param force is a boolean value indicating if the cache must remove the
	 * entries or let the GC does its job.
	 * @return the oid of the really evicted entries
	 * @throws CacheException is raised when entries are already unbound from
	 * the cache.
	 */
	Collection unbindAll(Collection oids, boolean force) throws CacheException;

	/**
	 * Try to evict unfixed instances.
	 * @param force is a boolean value indicating if the cache must remove the
	 * entries or let the GC does its job.
	 * @return the number of entry really evicted
	 * @throws CacheException
	 */
	Collection unbindUnfixed(boolean force) throws CacheException;
}
